# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.reactions_list_schema import ReactionsListSchema

class TestReactionsListSchema(unittest.TestCase):
    """ReactionsListSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReactionsListSchema:
        """Test ReactionsListSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReactionsListSchema`
        """
        model = ReactionsListSchema()
        if include_optional:
            return ReactionsListSchema(
                items = [
                    None
                    ],
                ok = True,
                paging = slack_beta_ti.models.paging_object.paging object(
                    count = 56, 
                    page = 56, 
                    pages = 56, 
                    per_page = 56, 
                    spill = 56, 
                    total = 56, ),
                response_metadata = [
                    ''
                    ]
            )
        else:
            return ReactionsListSchema(
                items = [
                    None
                    ],
                ok = True,
        )
        """

    def testReactionsListSchema(self):
        """Test ReactionsListSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
