# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_reminder import ObjsReminder

class TestObjsReminder(unittest.TestCase):
    """ObjsReminder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsReminder:
        """Test ObjsReminder
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsReminder`
        """
        model = ObjsReminder()
        if include_optional:
            return ObjsReminder(
                complete_ts = 56,
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'Rm8Q6ZGCKEC0L3O4GI7XH',
                recurring = True,
                text = '',
                time = 56,
                user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
            )
        else:
            return ObjsReminder(
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'Rm8Q6ZGCKEC0L3O4GI7XH',
                recurring = True,
                text = '',
                user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
        )
        """

    def testObjsReminder(self):
        """Test ObjsReminder"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
