# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthApi()

    def tearDown(self) -> None:
        pass

    def test_auth_revoke(self) -> None:
        """Test case for auth_revoke

        """
        pass

    def test_auth_test(self) -> None:
        """Test case for auth_test

        """
        pass


if __name__ == '__main__':
    unittest.main()
