# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.apps_permissions_info_schema import AppsPermissionsInfoSchema

class TestAppsPermissionsInfoSchema(unittest.TestCase):
    """AppsPermissionsInfoSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppsPermissionsInfoSchema:
        """Test AppsPermissionsInfoSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppsPermissionsInfoSchema`
        """
        model = AppsPermissionsInfoSchema()
        if include_optional:
            return AppsPermissionsInfoSchema(
                info = slack_beta_ti.models.apps_permissions_info_schema_info.apps_permissions_info_schema_info(
                    app_home = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            excluded_ids = [
                                None
                                ], 
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), 
                    channel = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(), 
                    group = , 
                    im = , 
                    mpim = , 
                    team = slack_beta_ti.models.apps_permissions_info_schema_info_team.apps_permissions_info_schema_info_team(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), ),
                ok = True
            )
        else:
            return AppsPermissionsInfoSchema(
                info = slack_beta_ti.models.apps_permissions_info_schema_info.apps_permissions_info_schema_info(
                    app_home = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            excluded_ids = [
                                None
                                ], 
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), 
                    channel = slack_beta_ti.models.apps_permissions_info_schema_info_app_home.apps_permissions_info_schema_info_app_home(), 
                    group = , 
                    im = , 
                    mpim = , 
                    team = slack_beta_ti.models.apps_permissions_info_schema_info_team.apps_permissions_info_schema_info_team(
                        resources = slack_beta_ti.models.resources_in_info_from_apps/permissions/info.resources in info from apps.permissions.info(
                            ids = [
                                None
                                ], 
                            wildcard = True, ), 
                        scopes = [
                            ''
                            ], ), ),
                ok = True,
        )
        """

    def testAppsPermissionsInfoSchema(self):
        """Test AppsPermissionsInfoSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
