# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class CallsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def calls_add(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_add_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_add_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        external_unique_id: Annotated[StrictStr, Field(description="An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.")],
        join_url: Annotated[StrictStr, Field(description="The URL required for a client to join the Call.")],
        external_display_id: Annotated[Optional[StrictStr], Field(description="An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        date_start: Annotated[Optional[StrictInt], Field(description="Call start time in UTC UNIX timestamp format")] = None,
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        created_by: Annotated[Optional[StrictStr], Field(description="The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.")] = None,
        users: Annotated[Optional[StrictStr], Field(description="The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_add

        Registers a new Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param external_unique_id: An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service. (required)
        :type external_unique_id: str
        :param join_url: The URL required for a client to join the Call. (required)
        :type join_url: str
        :param external_display_id: An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
        :type external_display_id: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :param date_start: Call start time in UTC UNIX timestamp format
        :type date_start: int
        :param title: The name of the Call.
        :type title: str
        :param created_by: The valid Slack user ID of the user who created this Call. When this method is called with a user token, the `created_by` field is optional and defaults to the authed user of the token. Otherwise, the field is required.
        :type created_by: str
        :param users: The list of users to register as participants in the Call. [Read more on how to specify users here](/apis/calls#users).
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_add_serialize(
            token=token,
            external_unique_id=external_unique_id,
            join_url=join_url,
            external_display_id=external_display_id,
            desktop_app_join_url=desktop_app_join_url,
            date_start=date_start,
            title=title,
            created_by=created_by,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_add_serialize(
        self,
        token,
        external_unique_id,
        join_url,
        external_display_id,
        desktop_app_join_url,
        date_start,
        title,
        created_by,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if external_unique_id is not None:
            _form_params.append(('external_unique_id', external_unique_id))
        if external_display_id is not None:
            _form_params.append(('external_display_id', external_display_id))
        if join_url is not None:
            _form_params.append(('join_url', join_url))
        if desktop_app_join_url is not None:
            _form_params.append(('desktop_app_join_url', desktop_app_join_url))
        if date_start is not None:
            _form_params.append(('date_start', date_start))
        if title is not None:
            _form_params.append(('title', title))
        if created_by is not None:
            _form_params.append(('created_by', created_by))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.add',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_end(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_end_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_end_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned when registering the call using the [`calls.add`](/methods/calls.add) method.")],
        duration: Annotated[Optional[StrictInt], Field(description="Call duration in seconds")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_end

        Ends a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned when registering the call using the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param duration: Call duration in seconds
        :type duration: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_end_serialize(
            token=token,
            id=id,
            duration=duration,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_end_serialize(
        self,
        token,
        id,
        duration,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if duration is not None:
            _form_params.append(('duration', duration))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.end',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_info_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_info_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:read`")],
        id: Annotated[StrictStr, Field(description="`id` of the Call returned by the [`calls.add`](/methods/calls.add) method.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_info

        Returns information about a Call.

        :param token: Authentication token. Requires scope: `calls:read` (required)
        :type token: str
        :param id: `id` of the Call returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_info_serialize(
            token=token,
            id=id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_info_serialize(
        self,
        token,
        id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/calls.info',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_participants_add(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_participants_add_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_participants_add_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_participants_add

        Registers new participants added to a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to add as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_add_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_participants_add_serialize(
        self,
        token,
        id,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.participants.add',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_participants_remove(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_participants_remove_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_participants_remove_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        users: Annotated[StrictStr, Field(description="The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users).")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_participants_remove

        Registers participants removed from a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param users: The list of users to remove as participants in the Call. [Read more on how to specify users here](/apis/calls#users). (required)
        :type users: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_participants_remove_serialize(
            token=token,
            id=id,
            users=users,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_participants_remove_serialize(
        self,
        token,
        id,
        users,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if users is not None:
            _form_params.append(('users', users))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.participants.remove',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def calls_update(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def calls_update_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def calls_update_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `calls:write`")],
        id: Annotated[StrictStr, Field(description="`id` returned by the [`calls.add`](/methods/calls.add) method.")],
        title: Annotated[Optional[StrictStr], Field(description="The name of the Call.")] = None,
        join_url: Annotated[Optional[StrictStr], Field(description="The URL required for a client to join the Call.")] = None,
        desktop_app_join_url: Annotated[Optional[StrictStr], Field(description="When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """calls_update

        Updates information about a Call.

        :param token: Authentication token. Requires scope: `calls:write` (required)
        :type token: str
        :param id: `id` returned by the [`calls.add`](/methods/calls.add) method. (required)
        :type id: str
        :param title: The name of the Call.
        :type title: str
        :param join_url: The URL required for a client to join the Call.
        :type join_url: str
        :param desktop_app_join_url: When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
        :type desktop_app_join_url: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._calls_update_serialize(
            token=token,
            id=id,
            title=title,
            join_url=join_url,
            desktop_app_join_url=desktop_app_join_url,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _calls_update_serialize(
        self,
        token,
        id,
        title,
        join_url,
        desktop_app_join_url,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if id is not None:
            _form_params.append(('id', id))
        if title is not None:
            _form_params.append(('title', title))
        if join_url is not None:
            _form_params.append(('join_url', join_url))
        if desktop_app_join_url is not None:
            _form_params.append(('desktop_app_join_url', desktop_app_join_url))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/calls.update',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )


