# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.chat_post_message_success_schema import ChatPostMessageSuccessSchema

class TestChatPostMessageSuccessSchema(unittest.TestCase):
    """ChatPostMessageSuccessSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatPostMessageSuccessSchema:
        """Test ChatPostMessageSuccessSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatPostMessageSuccessSchema`
        """
        model = ChatPostMessageSuccessSchema()
        if include_optional:
            return ChatPostMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = slack_beta_ti.models.message_object.Message object(
                    attachments = [
                        None
                        ], 
                    blocks = [
                        None
                        ], 
                    bot_id = slack_beta_ti.models.bot_id.bot_id(), 
                    bot_profile = slack_beta_ti.models.bot_profile_object.Bot Profile Object(
                        app_id = 'A8', 
                        deleted = True, 
                        icons = slack_beta_ti.models.icons.icons(), 
                        id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                        name = '', 
                        team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        updated = 56, ), 
                    client_msg_id = '', 
                    comment = slack_beta_ti.models.file_comment_object.File Comment Object(
                        comment = '', 
                        created = 56, 
                        id = 'Fc8Q6ZGCKEC0L3O4GI7XH', 
                        is_intro = True, 
                        is_starred = True, 
                        num_stars = 56, 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pinned_to = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        reactions = [
                            slack_beta_ti.models.reaction_object.Reaction object(
                                count = 56, 
                                name = '', 
                                users = [
                                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                    ], )
                            ], 
                        timestamp = 56, 
                        user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', ), 
                    display_as_bot = True, 
                    file = slack_beta_ti.models.file_object.file object(
                        channels = [
                            'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        comments_count = 56, 
                        created = 56, 
                        date_delete = 56, 
                        display_as_bot = True, 
                        editable = True, 
                        editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        external_id = '', 
                        external_type = '', 
                        external_url = '', 
                        filetype = '', 
                        groups = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        has_rich_preview = True, 
                        id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                        image_exif_rotation = 56, 
                        ims = [
                            'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        is_external = True, 
                        is_public = True, 
                        is_starred = True, 
                        is_tombstoned = True, 
                        last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        mimetype = '', 
                        mode = '', 
                        name = '', 
                        non_owner_editable = True, 
                        num_stars = 56, 
                        original_h = 56, 
                        original_w = 56, 
                        permalink = '', 
                        permalink_public = '', 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pretty_type = '', 
                        preview = '', 
                        public_url_shared = True, 
                        shares = slack_beta_ti.models.shares.shares(), 
                        size = 56, 
                        source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        state = '', 
                        thumb_1024 = '', 
                        thumb_1024_h = 56, 
                        thumb_1024_w = 56, 
                        thumb_160 = '', 
                        thumb_360 = '', 
                        thumb_360_h = 56, 
                        thumb_360_w = 56, 
                        thumb_480 = '', 
                        thumb_480_h = 56, 
                        thumb_480_w = 56, 
                        thumb_64 = '', 
                        thumb_720 = '', 
                        thumb_720_h = 56, 
                        thumb_720_w = 56, 
                        thumb_80 = '', 
                        thumb_800 = '', 
                        thumb_800_h = 56, 
                        thumb_800_w = 56, 
                        thumb_960 = '', 
                        thumb_960_h = 56, 
                        thumb_960_w = 56, 
                        thumb_tiny = '', 
                        timestamp = 56, 
                        title = '', 
                        updated = 56, 
                        url_private = '', 
                        url_private_download = '', 
                        user = '', 
                        user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        username = '', ), 
                    files = [
                        slack_beta_ti.models.file_object.file object(
                            comments_count = 56, 
                            created = 56, 
                            date_delete = 56, 
                            display_as_bot = True, 
                            editable = True, 
                            editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            external_id = '', 
                            external_type = '', 
                            external_url = '', 
                            filetype = '', 
                            has_rich_preview = True, 
                            id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                            image_exif_rotation = 56, 
                            is_external = True, 
                            is_public = True, 
                            is_starred = True, 
                            is_tombstoned = True, 
                            last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            mimetype = '', 
                            mode = '', 
                            name = '', 
                            non_owner_editable = True, 
                            num_stars = 56, 
                            original_h = 56, 
                            original_w = 56, 
                            permalink = '', 
                            permalink_public = '', 
                            pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                            pretty_type = '', 
                            preview = '', 
                            public_url_shared = True, 
                            shares = slack_beta_ti.models.shares.shares(), 
                            size = 56, 
                            source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            state = '', 
                            thumb_1024 = '', 
                            thumb_1024_h = 56, 
                            thumb_1024_w = 56, 
                            thumb_160 = '', 
                            thumb_360 = '', 
                            thumb_360_h = 56, 
                            thumb_360_w = 56, 
                            thumb_480 = '', 
                            thumb_480_h = 56, 
                            thumb_480_w = 56, 
                            thumb_64 = '', 
                            thumb_720 = '', 
                            thumb_720_h = 56, 
                            thumb_720_w = 56, 
                            thumb_80 = '', 
                            thumb_800 = '', 
                            thumb_800_h = 56, 
                            thumb_800_w = 56, 
                            thumb_960 = '', 
                            thumb_960_h = 56, 
                            thumb_960_w = 56, 
                            thumb_tiny = '', 
                            timestamp = 56, 
                            title = '', 
                            updated = 56, 
                            url_private = '', 
                            url_private_download = '', 
                            user = '', 
                            user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            username = '', )
                        ], 
                    icons = slack_beta_ti.models.icons.icons(), 
                    inviter = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    is_delayed_message = True, 
                    is_intro = True, 
                    is_starred = True, 
                    last_read = '0480728880.015280', 
                    latest_reply = '0480728880.015280', 
                    name = '', 
                    old_name = '', 
                    parent_user_id = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    permalink = '', 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    purpose = '', 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    reply_count = 56, 
                    reply_users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], 
                    reply_users_count = 56, 
                    source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    subscribed = True, 
                    subtype = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    text = '', 
                    thread_ts = '0480728880.015280', 
                    topic = '', 
                    ts = '0480728880.015280', 
                    type = '', 
                    unread_count = 56, 
                    upload = True, 
                    user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_profile = slack_beta_ti.models.objs_user_profile_short.objs_user_profile_short(
                        avatar_hash = '', 
                        display_name = '', 
                        display_name_normalized = '', 
                        image_72 = '', 
                        is_restricted = True, 
                        is_ultra_restricted = True, 
                        name = '', 
                        real_name = '', 
                        real_name_normalized = '', 
                        team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', ), 
                    user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    username = '', ),
                ok = True,
                ts = '0480728880.015280'
            )
        else:
            return ChatPostMessageSuccessSchema(
                channel = 'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                message = slack_beta_ti.models.message_object.Message object(
                    attachments = [
                        None
                        ], 
                    blocks = [
                        None
                        ], 
                    bot_id = slack_beta_ti.models.bot_id.bot_id(), 
                    bot_profile = slack_beta_ti.models.bot_profile_object.Bot Profile Object(
                        app_id = 'A8', 
                        deleted = True, 
                        icons = slack_beta_ti.models.icons.icons(), 
                        id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                        name = '', 
                        team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        updated = 56, ), 
                    client_msg_id = '', 
                    comment = slack_beta_ti.models.file_comment_object.File Comment Object(
                        comment = '', 
                        created = 56, 
                        id = 'Fc8Q6ZGCKEC0L3O4GI7XH', 
                        is_intro = True, 
                        is_starred = True, 
                        num_stars = 56, 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pinned_to = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        reactions = [
                            slack_beta_ti.models.reaction_object.Reaction object(
                                count = 56, 
                                name = '', 
                                users = [
                                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                    ], )
                            ], 
                        timestamp = 56, 
                        user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', ), 
                    display_as_bot = True, 
                    file = slack_beta_ti.models.file_object.file object(
                        channels = [
                            'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        comments_count = 56, 
                        created = 56, 
                        date_delete = 56, 
                        display_as_bot = True, 
                        editable = True, 
                        editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        external_id = '', 
                        external_type = '', 
                        external_url = '', 
                        filetype = '', 
                        groups = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        has_rich_preview = True, 
                        id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                        image_exif_rotation = 56, 
                        ims = [
                            'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        is_external = True, 
                        is_public = True, 
                        is_starred = True, 
                        is_tombstoned = True, 
                        last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        mimetype = '', 
                        mode = '', 
                        name = '', 
                        non_owner_editable = True, 
                        num_stars = 56, 
                        original_h = 56, 
                        original_w = 56, 
                        permalink = '', 
                        permalink_public = '', 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pretty_type = '', 
                        preview = '', 
                        public_url_shared = True, 
                        shares = slack_beta_ti.models.shares.shares(), 
                        size = 56, 
                        source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        state = '', 
                        thumb_1024 = '', 
                        thumb_1024_h = 56, 
                        thumb_1024_w = 56, 
                        thumb_160 = '', 
                        thumb_360 = '', 
                        thumb_360_h = 56, 
                        thumb_360_w = 56, 
                        thumb_480 = '', 
                        thumb_480_h = 56, 
                        thumb_480_w = 56, 
                        thumb_64 = '', 
                        thumb_720 = '', 
                        thumb_720_h = 56, 
                        thumb_720_w = 56, 
                        thumb_80 = '', 
                        thumb_800 = '', 
                        thumb_800_h = 56, 
                        thumb_800_w = 56, 
                        thumb_960 = '', 
                        thumb_960_h = 56, 
                        thumb_960_w = 56, 
                        thumb_tiny = '', 
                        timestamp = 56, 
                        title = '', 
                        updated = 56, 
                        url_private = '', 
                        url_private_download = '', 
                        user = '', 
                        user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        username = '', ), 
                    files = [
                        slack_beta_ti.models.file_object.file object(
                            comments_count = 56, 
                            created = 56, 
                            date_delete = 56, 
                            display_as_bot = True, 
                            editable = True, 
                            editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            external_id = '', 
                            external_type = '', 
                            external_url = '', 
                            filetype = '', 
                            has_rich_preview = True, 
                            id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                            image_exif_rotation = 56, 
                            is_external = True, 
                            is_public = True, 
                            is_starred = True, 
                            is_tombstoned = True, 
                            last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            mimetype = '', 
                            mode = '', 
                            name = '', 
                            non_owner_editable = True, 
                            num_stars = 56, 
                            original_h = 56, 
                            original_w = 56, 
                            permalink = '', 
                            permalink_public = '', 
                            pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                            pretty_type = '', 
                            preview = '', 
                            public_url_shared = True, 
                            shares = slack_beta_ti.models.shares.shares(), 
                            size = 56, 
                            source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            state = '', 
                            thumb_1024 = '', 
                            thumb_1024_h = 56, 
                            thumb_1024_w = 56, 
                            thumb_160 = '', 
                            thumb_360 = '', 
                            thumb_360_h = 56, 
                            thumb_360_w = 56, 
                            thumb_480 = '', 
                            thumb_480_h = 56, 
                            thumb_480_w = 56, 
                            thumb_64 = '', 
                            thumb_720 = '', 
                            thumb_720_h = 56, 
                            thumb_720_w = 56, 
                            thumb_80 = '', 
                            thumb_800 = '', 
                            thumb_800_h = 56, 
                            thumb_800_w = 56, 
                            thumb_960 = '', 
                            thumb_960_h = 56, 
                            thumb_960_w = 56, 
                            thumb_tiny = '', 
                            timestamp = 56, 
                            title = '', 
                            updated = 56, 
                            url_private = '', 
                            url_private_download = '', 
                            user = '', 
                            user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                            username = '', )
                        ], 
                    icons = slack_beta_ti.models.icons.icons(), 
                    inviter = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    is_delayed_message = True, 
                    is_intro = True, 
                    is_starred = True, 
                    last_read = '0480728880.015280', 
                    latest_reply = '0480728880.015280', 
                    name = '', 
                    old_name = '', 
                    parent_user_id = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    permalink = '', 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    purpose = '', 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    reply_count = 56, 
                    reply_users = [
                        'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], 
                    reply_users_count = 56, 
                    source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    subscribed = True, 
                    subtype = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    text = '', 
                    thread_ts = '0480728880.015280', 
                    topic = '', 
                    ts = '0480728880.015280', 
                    type = '', 
                    unread_count = 56, 
                    upload = True, 
                    user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    user_profile = slack_beta_ti.models.objs_user_profile_short.objs_user_profile_short(
                        avatar_hash = '', 
                        display_name = '', 
                        display_name_normalized = '', 
                        image_72 = '', 
                        is_restricted = True, 
                        is_ultra_restricted = True, 
                        name = '', 
                        real_name = '', 
                        real_name_normalized = '', 
                        team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', ), 
                    user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    username = '', ),
                ok = True,
                ts = '0480728880.015280',
        )
        """

    def testChatPostMessageSuccessSchema(self):
        """Test ChatPostMessageSuccessSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
