# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_users_conversations(self) -> None:
        """Test case for users_conversations

        """
        pass

    def test_users_delete_photo(self) -> None:
        """Test case for users_delete_photo

        """
        pass

    def test_users_get_presence(self) -> None:
        """Test case for users_get_presence

        """
        pass

    def test_users_identity(self) -> None:
        """Test case for users_identity

        """
        pass

    def test_users_info(self) -> None:
        """Test case for users_info

        """
        pass

    def test_users_list(self) -> None:
        """Test case for users_list

        """
        pass

    def test_users_lookup_by_email(self) -> None:
        """Test case for users_lookup_by_email

        """
        pass

    def test_users_profile_get(self) -> None:
        """Test case for users_profile_get

        """
        pass

    def test_users_profile_set(self) -> None:
        """Test case for users_profile_set

        """
        pass

    def test_users_set_active(self) -> None:
        """Test case for users_set_active

        """
        pass

    def test_users_set_photo(self) -> None:
        """Test case for users_set_photo

        """
        pass

    def test_users_set_presence(self) -> None:
        """Test case for users_set_presence

        """
        pass


if __name__ == '__main__':
    unittest.main()
