# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_user_profile import ObjsUserProfile

class TestObjsUserProfile(unittest.TestCase):
    """ObjsUserProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsUserProfile:
        """Test ObjsUserProfile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsUserProfile`
        """
        model = ObjsUserProfile()
        if include_optional:
            return ObjsUserProfile(
                always_active = True,
                api_app_id = 'AQ6ZGC',
                avatar_hash = '',
                bot_id = 'B8Q6ZGCKEC0L3O4GI7XH',
                display_name = '',
                display_name_normalized = '',
                is_app_user = True,
                is_custom_image = True,
                last_avatar_image_hash = '',
                memberships_count = 56,
                phone = '',
                pronouns = '',
                real_name = '',
                real_name_normalized = '',
                skype = '',
                status_default_emoji = '',
                status_default_text = '',
                status_emoji = '',
                status_expiration = 56,
                status_text = '',
                team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                title = '',
                updated = 56,
                user_id = ''
            )
        else:
            return ObjsUserProfile(
                avatar_hash = '',
                display_name = '',
                display_name_normalized = '',
                phone = '',
                real_name = '',
                real_name_normalized = '',
                skype = '',
                status_emoji = '',
                status_text = '',
                title = '',
        )
        """

    def testObjsUserProfile(self):
        """Test ObjsUserProfile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
