# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_file import ObjsFile

class TestObjsFile(unittest.TestCase):
    """ObjsFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsFile:
        """Test ObjsFile
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsFile`
        """
        model = ObjsFile()
        if include_optional:
            return ObjsFile(
                channels = [
                    'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                comments_count = 56,
                created = 56,
                date_delete = 56,
                display_as_bot = True,
                editable = True,
                editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                external_id = '',
                external_type = '',
                external_url = '',
                filetype = '',
                groups = [
                    'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                has_rich_preview = True,
                id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                image_exif_rotation = 56,
                ims = [
                    'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                is_external = True,
                is_public = True,
                is_starred = True,
                is_tombstoned = True,
                last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                mimetype = '',
                mode = '',
                name = '',
                non_owner_editable = True,
                num_stars = 56,
                original_h = 56,
                original_w = 56,
                permalink = '',
                permalink_public = '',
                pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(),
                pinned_to = [
                    'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                pretty_type = '',
                preview = '',
                public_url_shared = True,
                reactions = [
                    slack_beta_ti.models.reaction_object.Reaction object(
                        count = 56, 
                        name = '', 
                        users = [
                            'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], )
                    ],
                shares = None,
                size = 56,
                source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                state = '',
                thumb_1024 = '',
                thumb_1024_h = 56,
                thumb_1024_w = 56,
                thumb_160 = '',
                thumb_360 = '',
                thumb_360_h = 56,
                thumb_360_w = 56,
                thumb_480 = '',
                thumb_480_h = 56,
                thumb_480_w = 56,
                thumb_64 = '',
                thumb_720 = '',
                thumb_720_h = 56,
                thumb_720_w = 56,
                thumb_80 = '',
                thumb_800 = '',
                thumb_800_h = 56,
                thumb_800_w = 56,
                thumb_960 = '',
                thumb_960_h = 56,
                thumb_960_w = 56,
                thumb_tiny = '',
                timestamp = 56,
                title = '',
                updated = 56,
                url_private = '',
                url_private_download = '',
                user = '',
                user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                username = ''
            )
        else:
            return ObjsFile(
        )
        """

    def testObjsFile(self):
        """Test ObjsFile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
