# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.admin_teams_settings_api import AdminTeamsSettingsApi


class TestAdminTeamsSettingsApi(unittest.TestCase):
    """AdminTeamsSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminTeamsSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_admin_teams_settings_info(self) -> None:
        """Test case for admin_teams_settings_info

        """
        pass

    def test_admin_teams_settings_set_default_channels(self) -> None:
        """Test case for admin_teams_settings_set_default_channels

        """
        pass

    def test_admin_teams_settings_set_description(self) -> None:
        """Test case for admin_teams_settings_set_description

        """
        pass

    def test_admin_teams_settings_set_discoverability(self) -> None:
        """Test case for admin_teams_settings_set_discoverability

        """
        pass

    def test_admin_teams_settings_set_icon(self) -> None:
        """Test case for admin_teams_settings_set_icon

        """
        pass

    def test_admin_teams_settings_set_name(self) -> None:
        """Test case for admin_teams_settings_set_name

        """
        pass


if __name__ == '__main__':
    unittest.main()
