# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.files_remote_api import FilesRemoteApi


class TestFilesRemoteApi(unittest.TestCase):
    """FilesRemoteApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesRemoteApi()

    def tearDown(self) -> None:
        pass

    def test_files_remote_add(self) -> None:
        """Test case for files_remote_add

        """
        pass

    def test_files_remote_info(self) -> None:
        """Test case for files_remote_info

        """
        pass

    def test_files_remote_list(self) -> None:
        """Test case for files_remote_list

        """
        pass

    def test_files_remote_remove(self) -> None:
        """Test case for files_remote_remove

        """
        pass

    def test_files_remote_share(self) -> None:
        """Test case for files_remote_share

        """
        pass

    def test_files_remote_update(self) -> None:
        """Test case for files_remote_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
