# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.admin_conversations_api import AdminConversationsApi


class TestAdminConversationsApi(unittest.TestCase):
    """AdminConversationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminConversationsApi()

    def tearDown(self) -> None:
        pass

    def test_admin_conversations_archive(self) -> None:
        """Test case for admin_conversations_archive

        """
        pass

    def test_admin_conversations_convert_to_private(self) -> None:
        """Test case for admin_conversations_convert_to_private

        """
        pass

    def test_admin_conversations_create(self) -> None:
        """Test case for admin_conversations_create

        """
        pass

    def test_admin_conversations_delete(self) -> None:
        """Test case for admin_conversations_delete

        """
        pass

    def test_admin_conversations_disconnect_shared(self) -> None:
        """Test case for admin_conversations_disconnect_shared

        """
        pass

    def test_admin_conversations_get_conversation_prefs(self) -> None:
        """Test case for admin_conversations_get_conversation_prefs

        """
        pass

    def test_admin_conversations_get_teams(self) -> None:
        """Test case for admin_conversations_get_teams

        """
        pass

    def test_admin_conversations_invite(self) -> None:
        """Test case for admin_conversations_invite

        """
        pass

    def test_admin_conversations_rename(self) -> None:
        """Test case for admin_conversations_rename

        """
        pass

    def test_admin_conversations_search(self) -> None:
        """Test case for admin_conversations_search

        """
        pass

    def test_admin_conversations_set_conversation_prefs(self) -> None:
        """Test case for admin_conversations_set_conversation_prefs

        """
        pass

    def test_admin_conversations_set_teams(self) -> None:
        """Test case for admin_conversations_set_teams

        """
        pass

    def test_admin_conversations_unarchive(self) -> None:
        """Test case for admin_conversations_unarchive

        """
        pass


if __name__ == '__main__':
    unittest.main()
